LogEvent class

A single log record handed to a LogPrinter.

Annotations

Constructors

LogEvent(LogLevel level, Object? message, {Object? error, StackTrace? stackTrace, DateTime? time})

Properties

error Object?
final
hashCode int
The hash code for this object.
no setterinherited
level LogLevel
final
message Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final
time DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited